Learn R Programming

cosa (version 2.0.0)

cosa-package: Bound Constrained Optimal Design of MRDDs and MRTs

Description

Bound Constrained Optimal Sample Allocation (BCOSA) functions are designed to optimize sample sizes at one or more levels subject to budget, statistical power, or effect size constraints. BCOSA can be found in the following forms; (i) under budgetary constraints given marginal costs per unit while minimizing sampling variance of the treatment effect (or, alternatively, while maximizing power rate), (ii) under statistical power or effect size (ES) constraints while minimizing the total cost, and (iii) under sample size constraints for one or more levels along with (i) or (ii). Specifying rhots = 0 or order = 0 produces results equivalent to corresponding random assignment designs, which means there is no relationship between the treatment [random] and the score variable. Therefore, BCOSA functions also allow optimization of proportion of treatment allocation (p) under unequal marginal costs when primary constraint is placed on the total cost. Different starting values and algorithms may produce different results when marginal cost information is not provided and sample sizes at two or more levels and p are optimized. In such cases, experimenting different starting values and/or comparing several algorithms may faciliate decisions regarding sample sizes and p.

Designs available in cosa package:

Design Total Levels Treatment Level Top Level
ird1r1 1 1 random
bird2r1 2 1 random
bird2f1 2 1 fixed
bird3r1 3 1 random
bird4r1 4 1 random
crd2r2 2 2 random
bcrd3f2 3 2 fixed
bcrd3r2 3 2 random
bcrd4r2 4 2 random
crd3r3 3 3 random
bcrd4f3 4 3 fixed
bcrd4r3 4 3 random

ird: individual-level regression discontinuity. bird: blocked individual-level regression discontinuity. crd: cluster-level regression discontinuity. bcrd: blocked cluster-level regression discontinuity.

Design parameters follow a sequential order. Numbers at the end of a sequential parameter refers to the corresponding level. For example rho2 is the proportion of variance in the outcome between level 2 units, rho3 is the proportion of variance in the outcome between level 3 units. Similiarly, r21 is the proportion of the variance in the outcome explained by level 1 covariates, r22 is the proportion of the variance in the outcome explained by level 2 covariates and so on. Similiar naming conventions applies to other design parameters.

Arguments